\name{concor}
\title{Relative links of several subsets of variables}
\description{Relative links of several subsets of variables Yj with another set X. SUCCESSIVE SOLUTIONS}
\keyword{}
\keyword{}
\alias{concor}

\usage{
concor(x,y,py,r)
}

\arguments{
\item{x,y}{are n x p and n x q matrices of p and q centered columns}
\item{py}{is a row vector which contains the numbers qi, i=1,...,ky, of the ky subsets yi of y : sum(qi)=sum(py)=q. py is the partition vector of y}
\item{r}{is the wanted number of successive solutions}
}

\value{
list with following components
\item{u}{is a p x r matrix of axes in Rp relative to x; u'*u = Identity}
\item{v}{is a q x r matrix of ky row blocks vi (qi x r) of axes in Rqi relative to yi; vi'*vi = Identity}
\item{V}{is a q x r matrix of axes in Rq relative to y; V'*V = Identity}
\item{cov2}{is a ky x r matrix; each column k contains ky squared covariances \eqn{\mbox{cov}(x*u[,k],y_i*v_i[,k])^2}, the partial measures of link}
}

\details{
The first solution calculates 1+kx normed vectors: the vector u[:,1]
of Rp associated to the ky vectors vi[:,1]'s of Rqi, by maximizing
\eqn{\sum_i \mbox{cov}(x*u[,k],y_i*v_i[,k])^2}, with 1+ky norm constraints on the
axes. A component x*u[,k] is associated to ky partial components
yi*vi[,k] and to a global component y*V[,k].  \eqn{\mbox{cov}(x*u[,k],y*V[,k])^2 =
\sum \mbox{cov}(x*u[,k],y_i*v_i[,k])^2}. y*V[,k] is a global component of the
components yi*vi[,k].

The second solution is obtained from the same criterion, but after
replacing each yi by \eqn{y_i-y_i*v_i[,1]*v_i[,1]'}.  And so on for the
successive solutions 1,2,...,r.  The biggest number of solutions may
be r=inf(n,p,qi), when the x'*yi's are supposed with full rank; then
rmax=min(c(min(py),n,p)).  For a set of r solutions, the matrix u'X'YV
is diagonal and the matrices u'X'Yjvj are triangular (good partition
of the link by the solutions).  concor.m is the svdcp.m function
applied to the matrix x'y.
}

\references{
Lafosse R. & Hanafi M.(1997) Concordance d'un tableau avec K tableaux:
Definition de K+1 uples synthetiques. Revue de Statistique Appliquee
vol.45,n.4.
}

\examples{
# To make some "GPA" : so, by posing the compromise X = Y,
# "procrustes" rotations to the "compromise X" then are :
# Yj*(vj*u').

x<-matrix(runif(50),10,5);y<-matrix(runif(90),10,9)
x<-scale(x);y<-scale(y)
co<-concor(x,y,c(3,2,4),2)
((t(x\%*\%co$u[,1])\%*\%y[,1:3]\%*\%co$v[1:3,1])/10)^2;co$cov2[1,1] 
t(x\%*\%co$u)\%*\%y\%*\%co$V
}

\eof
\name{concorcano}
\title{Canonical analysis of several sets with another set}
\description{Relative proximities of several subsets of variables Yj with another set X. SUCCESSIVE SOLUTIONS}
\keyword{}
\keyword{}
\alias{concorcano}

\usage{
concorcano(x,y,py,r)
}

\arguments{
\item{x}{is a n x p matrix of p centered variables}
\item{y}{is a n x q matrix of q centered variables}
\item{py}{is a row vector which contains the numbers qi, i=1,...,ky, of
  the ky subsets yi of y : \eqn{\sum_i q_i}=sum(py)=q. py is the partition vector of y}
\item{r}{is the wanted number of successive solutions}
}

\value{
list with following components
\item{cx}{is n x r matrix of the r canonical components of x}
\item{cy}{is n.ky x r matrix. The ky blocks cyi of the rows n*(i-1)+1 : n*i contain the r canonical components relative to Yi}
\item{rho2}{is a ky x r matrix; each column k contains ky squared
  canonical correlations \eqn{\rho(cx[,k],cy_i[,k])^2}}
}

\details{
The first solution calculates a standardized canonical component
cx[,1] of x associated to ky standardized components cyi[,1] of yi by
maximizing \eqn{\sum_i \rho(cx[,1],cy_i[,1])^2}.

The second solution is obtained from the same criterion, with ky
orthogonality constraints for having rho(cyi[,1],cyi[,2])=0 (that
implies rho(cx[,1],cx[,2])=0).  For each of the 1+ky sets, the r
canonical components are 2 by 2 zero correlated.

The ky matrices (cx)'*cyi are triangular.

This function uses concor function.
}

\references{
Hanafi & Lafosse (2001) Generalisation de la regression lineaire
simple pour analyser la dependance de K ensembles de variables avec un
K+1 eme.  Revue de Statistique Appliquee vol.49, n.1
}

\examples{
x<-matrix(runif(50),10,5);y<-matrix(runif(90),10,9)
x<-scale(x);y<-scale(y)
ca<-concorcano(x,y,c(3,2,4),2)
diag(t(ca$cx)\%*\%ca$cy[1:10,]/10)^2
ca$rho2[1,]
}


\eof
\name{concoreg}
\title{Redundancy of sets yj by one set x}
\description{Regression of several subsets of variables Yj by another set X. SUCCESSIVE SOLUTIONS}
\keyword{}
\keyword{}
\alias{concoreg}

\usage{
concoreg(x,y,py,r)
}

\arguments{
\item{x}{is a \eqn{n \times p}{n x p} matrix of p centered explanatory variables}
\item{y}{is a \eqn{n \times q}{n x q} matrix of q centered variables}
\item{py}{is a row vector which contains the numbers \eqn{q_i,
    i=1,...,ky}, of the ky subsets \eqn{y_i} of y : \eqn{\sum_i q_i} =
    sum(py) = q. py is the partition vector of y} \item{r}{is the wanted
    number of successive solutions} }

\value{
list with following components
\item{cx}{the \eqn{n \times r}{n x r} matrix of the r explanatory components}
\item{v}{is a \eqn{q \times r}{q x r} matrix of ky row blocks \eqn{v_i} (\eqn{q_i \times r}{q_i x r}) of axes in Rqi relative to yi; \eqn{v_i'*v_i = \mbox{Id}}}
\item{V}{is a \eqn{q \times r}{q x r} matrix of axes in Rq relative to y; \eqn{V'*V = \mbox{Id}}}
\item{varexp}{is a \eqn{ky \times r}{ky x r} matrix; each column k contains ky explained variances \eqn{\rho(cx[,k],y_i*v_i[,k])^2 \mbox{var}(y_i*v_i[,k])}}
}

\details{

The first solution calculates 1+ky normed vectors: the component
cx[,1] in \eqn{R^n} associated to the ky vectors vi[,1]'s of \eqn{R^{q_i}}, by
maximizing \eqn{varexp1=\sum_i \rho(cx[,1],y_i*v_i[,1])^2 \mbox{var}(y_i*v_i[,1]))}, with
\eqn{1+ky} norm constraints. A explanatory component cx[,k] is associated to
ky partial explained components yi*vi[,k] and also to a global explained
component y*V[,k]. \eqn{\rho(cx[,k],y*V[,k])^2 \mbox{var}(y*V[,k])= \mbox{varexpk}}.  The
total explained variance by the first solution is maximal.

The second solution is obtained from the same criterion, but after
replacing each yi by \eqn{y_i-y_i*v_i[,1]*v_i[,1]'}.  And so on for the
successive solutions 1,2,...,r .  The biggest number of solutions may
be \eqn{r=inf(n,p,q_i)}, when the matrices x'*yi are supposed with full rank.
For a set of r solutions, the matrix (cx)'*y*V is diagonal : "on
average", the explanatory component of one solution is only linked
with the components explained by this explanatory, and is not linked
with the explained components of the other solutions.  The matrices
\eqn{(cx)'*y_j*v_j} are triangular : the explanatory component of one solution
is not linked with each of the partial components explained in the
following solutions.  The definition of the explanatory components
depends on the partition vector py from the second solution.

This function is using concor function 
}

\references{
Hanafi & Lafosse (2001) Generalisation de la regression lineaire
simple pour analyser la dependance de K ensembles de variables avec un
K+1 eme. Revue de Statistique Appliquee vol.49, n.1.

Chessel D. & Hanafi M. (1996) Analyses de la Co-inertie de K nuages de
points.  Revue de Statistique Appliquee vol.44, n.2. (this ACOM
analysis of one multiset is obtained by the command : concoreg(Y,Y,py,r))
}

\examples{
x<-matrix(runif(50),10,5);y<-matrix(runif(90),10,9)
x<-scale(x);y<-scale(y)
co<-concoreg(x,y,c(3,2,4),2)
((t(co$cx[,1])\%*\%y[,1:3]\%*\%co$v[1:3,1])/10)^2;co$varexp[1,1]
t(co$cx)\%*\%co$cx /10
diag(t(co$cx)\%*\%y\%*\%co$V/10)^2
sum(co$varexp[,1]);sum(co$varexp[,2])
}


\eof
\name{concorgm}
\title{Analyzing a set of partial links between Xi and Yj}
\description{Analyzing a set of partial links between Xi and Yj, SUCCESSIVE SOLUTIONS}
\keyword{}
\keyword{}
\alias{concorgm}

\usage{
concorgm(x,px,y,py,r)
}

\arguments{
\item{x}{is a n x p matrix of p centered variables}
\item{y}{is a n x q matrix of q centered variables}
\item{px}{is a row vector which contains the numbers pi, i=1,...,kx, of the kx subsets xi of x : sum(pi)=sum(px)=p. px is the partition vector of x}
\item{py}{is the partition vector of y with ky subsets yj, j=1,...,ky}
\item{r}{is the wanted number of successive solutions rmax <= min(min(px),min(py),n)}
}

\value{
list with following components
\item{u}{is a p x r matrix of kx row blocks ui (pi x r), the orthonormed partial axes of xi; associated partial components: xi*ui}
\item{v}{is a q x r matrix of ky row blocks vj (qj x r), the orthonormed partial axes of yj; associated partial components: yj*vj}
\item{cov2}{is a kx x ky x r array; for r fixed to k, the matrix contains kxky  squared covariances \eqn{\mbox{cov2}(x_i*u_i[,k],y_j*v_j[,k])^2}, the partial links between xi and yj measured with the solution k.}
}

\details{
For the first solution, \eqn{\sum_i \sum_j \mbox{cov2}(x_i*u_i[,1],y_j*v_j[,1])} is the
optimized criterion. The second solution is calculated from the same
criterion, but with \eqn{x_i-x_i*u_i[,1]*u_i[,1]'} and \eqn{y_j-y_j*v_j[,1]*v_j[,1]'}
instead of the kx+ky matrices xi and yj. And so on for the other
solutions.  When kx=1 (px=p), take concor.m

This function uses the svdbip function.
}

\references{
Kissita, Cazes, Hanafi & Lafosse (2004) Deux methodes d'analyse
factorielle du lien entre deux tableaux de variables
partitionnes. Revue de Statistique Applique, Vol 52, n 3, 73-92.
}

\examples{
x<-matrix(runif(50),10,5);y<-matrix(runif(90),10,9)
x<-scale(x);y<-scale(y)
cg<-concorgm(x,c(2,3),y,c(3,2,4),2)
diag(t(x[,1:2]\%*\%cg$u[1:2,])\%*\%y[,1:3]\%*\%cg$v[1:3,]/10)^2
cg$cov2[1,1,]
}


\eof
\name{concorgmcano}
\title{Canonical analysis of subsets Yj with subsets Xi}
\description{Canonical analysis of subsets Yj with subsets Xi. Relative valuations by squared correlations of the proximities of subsets Xi with subsets Yj. SUCCESSIVE SOLUTIONS}
\keyword{}
\keyword{}
\alias{concorgmcano}

\usage{
concorgmcano(x,px,y,py,r)
}

\arguments{
\item{x}{is a n x p matrix of p centered variables}
\item{y}{is a n x q matrix of q centered variables}
\item{px}{is a row vector which contains the numbers pi, i=1,...,kx, of
  the kx subsets xi of x : \eqn{\sum_i p_i}=sum(px)=p. px is the partition vector of x}
\item{py}{is the partition vector of y with ky subsets yj, j=1,...,ky}
\item{r}{is the wanted number of successive solutions rmax <= min(min(px),min(py),n)}
}

\value{
list with following components
\item{cx}{is a n.kx x r matrix of kx row blocks cxi (n x r). Each row block contains r partial canonical components}
\item{cy}{is a n.ky x r matrix of ky row blocks cyj (n x r). Each row block contains r partial canonical components}
\item{rho2}{is a kx x ky x r array; for a fixed solution k, rho2[,,k]
  contains kxky squared correlations \eqn{rho2(cx[n*(i-1)+1:n*i,k],cy[n*(j-1)+1:n*j,k])}, simultaneously calculated between all the yj with all the xi}
}

\details{
For the first solution, \eqn{sum_i sum_j \mbox{rho2}(cx_i[,1],cy_j[,1])} is the
optimized criterion. The other solutions are calculated from the same
criterion, but with orthogonalities for having two by two zero
correlated the canonical components defined for each xi, and also for
those defined for each yj.  Each solution associates kx canonical
components to ky canonical components.  When kx =1 (px=p), take
concorcano function

This function uses the concorgm function
}

\references{
Kissita G., Analyse canonique generalisee avec tableau de reference generalisee. Thesis, Ceremade Paris 9 Dauphine (2003).
}

\examples{
x<-matrix(runif(50),10,5);y<-matrix(runif(90),10,9)
x<-scale(x);y<-scale(y)
cc<-concorgmcano(x,c(2,3),y,c(3,2,4),2)
diag(t(cc$cx[1:10,])\%*\%cc$cy[1:10,]/10)^2
cc$rho2[1,1,] 
}


\eof
\name{concorgmreg}
\title{Regression of subsets Yj by subsets Xi}
\description{Regression of subsets Yj by subsets Xi for comparing all the explanatory-explained pairs (Xi,Yj). SUCCESSIVE SOLUTIONS}
\keyword{}
\keyword{}
\alias{concorgmreg}

\usage{
concorgmreg(x,px,y,py,r)
}

\arguments{
\item{x}{is a n x p matrix of p centered variables}
\item{y}{is a n x q matrix of q centered variables}
\item{px}{is a row vector which contains the numbers pi, i=1,...,kx, of
  the kx subsets xi of x : \eqn{\sum p_i}=sum(px)=p. px is the partition
  vector of the columns of x.}
\item{py}{is the partition vector of y with ky subsets yj, j=1,...,ky. sum(py)=q}
\item{r}{is the wanted number of successive solutions rmax <= min(min(px),min(py),n)}
}

\value{
list with following components
\item{cx}{is a n.kx x r matrix of kx row blocks cxi (n x r). Each row block contains r partial explanatory components}
\item{v}{is a q x r matrix of ky row blocks vj (qj x r), the orthonormed partial axes of yj; The components yj*vj are the explained components}
\item{varexp}{is a kx x ky x r array; for a fixed solution k, the matrix varexp[,,k] contains kxky explained variances obtained by a simultaneous regression of all the yj by all the xi, so the values \eqn{\mbox{rho2}(cx[n*(i-1)+1:n*i,k],y_j*v_j[,k]) var(y_j*v_j[,k])}}
}

\details{
For the first solution, \eqn{\sum_i \sum_j \mbox{rho2}(cx_i[,1],y_j*v_j[,1])
\mbox{var}(y_j*v_j[,1])} is the optimized criterion. The second solution is
calculated from the same criterion, but with \eqn{y_j-y_j*v_j[,1]*v_j[,1]'}
instead of the matrices yj and with orthogonalities for having two by
two zero correlated the explanatory components defined for each matrix
xi. And so on for the other solutions. One solution k associates kx
explanatory components (in cx[,k]) to ky explained components. When
kx =1 (px=p), take concoreg function

This function uses the concorgm function
}

\references{
Hanafi & Lafosse (2004) Regression of a multi-set by another based on an
extension of the SVD. COMPSTAT'2004 Symposium
}

\examples{
x<-matrix(runif(50),10,5);y<-matrix(runif(90),10,9)
x<-scale(x);y<-scale(y)
cr<-concorgmreg(x,c(2,3),y,c(3,2,4),2)
diag(t(cr$cx[1:10,])\%*\%y[,1:3]\%*\%cr$v[1:3,]/10)^2
cr$varexp[1,1,]
}


\eof
\name{concors}
\title{"simultaneous  concorgm"}
\description{concorgm with the set of r solutions simultaneously optimized}
\keyword{}
\keyword{}
\alias{concors}

\usage{
concors(x,px,y,py,r)
}

\arguments{
\item{x}{is a n x p matrix of p centered variables}
\item{y}{is a n x q matrix of q centered variables}
\item{px}{is a row vector which contains the numbers pi, i=1,...,kx, of
  the kx subsets xi of x : \eqn{\sum_i p_i}=sum(px)=p. px is the partition vector of x}
\item{py}{is the partition vector of y with ky subsets yj, j=1,...,ky}
\item{r}{is the wanted number of successive solutions rmax <= min(min(px),min(py),n)}
}

\value{
list with following components
\item{u}{is a p x r matrix of kx row blocks ui (pi x r), the orthonormed partial axes of xi; associated partial components: xi*ui}
\item{v}{is a q x r matrix of ky row blocks vj (qj x r), the orthonormed partial axes of yj; associated partial components: yj*vj}
\item{cov2}{is a kx x ky x r array; for r fixed to k, the matrix contains kxky  squared covariances \eqn{\mbox{cov}(x_i*u_i[,k],y_j*v_j[,k])^2}, the partial links between xi and yj measured with the solution k}
}

\details{
This function uses the svdbips function
}

\references{See svdbips}

\examples{
x<-matrix(runif(50),10,5);y<-matrix(runif(90),10,9)
x<-scale(x);y<-scale(y)
cs<-concors(x,c(2,3),y,c(3,2,4),2)
diag(t(x[,1:2]\%*\%cs$u[1:2,])\%*\%y[,1:3]\%*\%cs$v[1:3,]/10)^2
cs$cov2[1,1,]
}


\eof
\name{concorscano}
\title{"simultaneous concorgmcano"}
\description{concorgmcano with the set of r solutions simultaneously optimized}
\keyword{}
\keyword{}
\alias{concorscano}

\usage{
concorscano(x,px,y,py,r)
}

\arguments{
\item{x}{is a n x p matrix of p centered variables}
\item{y}{is a n x q matrix of q centered variables}
\item{px}{is a row vector which contains the numbers pi, i=1,...,kx, of
  the kx subsets xi of x : \eqn{\sum_i p_i}=sum(px)=p. px is the partition vector of x}
\item{py}{is the partition vector of y with ky subsets yj, j=1,...,ky}
\item{r}{is the wanted number of successive solutions rmax <= min(min(px),min(py),n)}
}


\value{
list with following components
\item{cx}{is a n.kx x r matrix of kx row blocks cxi (n x r). Each row block contains r partial canonical components} 
\item{cy}{is a n.ky x r matrix of ky row blocks cyj (n x r). Each row block contains r partial canonical components}
\item{rho2}{is a kx x ky x r array; for a fixed solution k, rho2[,,k] contains kxky squared correlations \eqn{\rho(cx[n*(i-1)+1:n*i,k],cy[n*(j-1)+1:n*j,k])^2}, simultaneously calculated between all the yj with all the xi}
}

\details{
This function uses the concors function
}

\references{See svdbips}

\examples{
x<-matrix(runif(50),10,5);y<-matrix(runif(90),10,9)
x<-scale(x);y<-scale(y)
cca<-concorscano(x,c(2,3),y,c(3,2,4),2)
diag(t(cca$cx[1:10,])\%*\%cca$cy[1:10,]/10)^2
cca$rho2[1,1,]
}


\eof
\name{concorsreg}
\title{"simultaneous concorgmreg"}
\description{concorgmreg with the set of r solutions simultaneously optimized}
\keyword{}
\keyword{}
\alias{concorsreg}

\usage{
concorsreg(x,px,y,py,r)
}

\arguments{
\item{x}{is a n x p matrix of p centered variables}
\item{y}{is a n x q matrix of q centered variables}
\item{px}{is a row vector which contains the numbers pi, i=1,...,kx, of the kx subsets xi of x : sum(pi)=sum(px)=p. px is the partition vector of x}
\item{py}{is the partition vector of y with ky subsets yj, j=1,...,ky}
\item{r}{is the wanted number of successive solutions rmax <= min(min(px),min(py),n)}
}

\value{
list with following components
\item{cx}{is a n.kx x r matrix of kx row blocks cxi (n x r). Each row block contains r partial explanatory components}
\item{v}{is a q x r matrix of ky row blocks vj (qj x r), the orthonormed partial axes of yj; The components yj*vj are the explained components.}
\item{varexp}{is a kx x ky x r array; for a fixed solution k, the matrix
 varexp[,,k] contains kxky explained variances obtained by a simultaneous
 regression of all the yj by all the xi, so the values \eqn{\mbox{rho2}(cx[n*(i-1)+1:n*i,k],y_j*v_j[,k]) var(y_j*v_j[,k])}}
}

\details{
This function uses the concors function
}

\references{See svdbips}

\examples{
x<-matrix(runif(50),10,5);y<-matrix(runif(90),10,9)
x<-scale(x);y<-scale(y)
crs<-concorsreg(x,c(2,3),y,c(3,2,4),2)
diag(t(crs$cx[1:10,])\%*\%y[,1:3]\%*\%crs$v[1:3,]/10)^2
crs$varexp[1,1,]
}


\eof
\name{svdbip}
\title{SVD for one bipartitioned matrix x}
\description{SVD for bipartitioned matrix x. r successive Solutions}
\keyword{}
\keyword{}
\alias{svdbip}

\usage{
svdbip(x,K,H,r)
}

\arguments{
\item{x}{is a p x q matrix}
\item{K}{is a row vector which contains the numbers pk, k=1,...,kx, of the partition of x with kx row blocks : \code{sum(pk)=p}}
\item{H}{is a row vector which contains the numbers qh, h=1,...,ky, of the partition of x with ky column blocks : sum(qh)=q}
\item{r}{is the wanted number of successive solutions}
}

\value{
list with following components
\item{u}{is a p x r matrix of kx row blocks uk (pk x r); uk'*uk = Identity.}
\item{v}{is a q x r matrix of ky row blocks vh (qh x r); vh'*vh = Identity}
\item{s2}{is a kx x ky x r array; with r fixed, each matrix contains kxky values \eqn{(u_h'*x_{kh}*v_k)^2}, the partial (squared) singular values relative to xkh.}
}

\details{

The first solution calculates kx+ky normed vectors: kx vectors uk[:,1]
of \eqn{R^{p_k}} associated to ky vectors vh[:,1]'s of \eqn{R^{q_h}}, by
maximizing \eqn{\sum_k \sum_h (u_k[:,1]'*x_{kh}*v_h[:,1])^2}, with kx+ky
norm constraints. A value \eqn{(u_k[,1]'*x_{kh}*v_h[,1])^2} measures the
relative link between \eqn{R^{p_k}} and \eqn{R^{q_h}} associated to the block xkh.

The second solution is obtained from the same criterion, but after
replacing each xhk by xkh-xkh*vh*vh'-uk*uk'xkh+uk*uk'xkh*vh*vh'.  And
so on for the successive solutions 1,2,...,r .  The biggest number of
solutions may be r=inf(pk,qh), when the xkh's are supposed with full
rank; then rmax=min([min(K),min(H)]).

When K=p (or H=q, with t(x)), svdcp function is better.  When H=q and
K=p, it is the usual svd (with squared singular values).

Convergence of algorithm may be not global. So the below proposed
initialisation of the algorithm may be not very suitable for some data
sets.  Several different random initialisations with normed vectors
might be considered and the best result then choosen.
}

\references{
Kissita G., Cazes P., Hanafi M. & Lafosse (2004) Deux methodes d'analyse
factorielle du lien entre deux tableaux de variables partitiones. Revue de
Statistique Appliquee.}

\examples{
x<-matrix(runif(200),10,20)
s<-svdbip(x,c(3,4,3),c(5,15),3)
zu<-cbind(x[1:3,1:5]\%*\%s$v[1:5,1],x[1:3,6:20]\%*\%s$v[6:20,1])
czu<-svd(zu);
czu$u[,1]\%*\%s$u[1:3,2:3]
czu$u[,1] # is a compromise between the vectors xj*vj[,1],
# orthogonal to the partial vectors uk[,k] relative to the
# following solutions (k>1); (in a same way, the singular
# vectors ui and vj of an usual SVD of x verifies ui'*(x*vj)=0,
#when i is not equal to j)
}


\eof
\name{svdbip2}
\title{SVD for bipartitioned matrix x}
\description{SVD for bipartitioned matrix x. r successive Solutions. As SVDBIP, but with another algorithm and another initialisation}
\keyword{}
\keyword{}
\alias{svdbip2}

\usage{
svdbip2(x,K,H,r)
}

\arguments{
\item{x}{is a p x q matrix}
\item{K}{is a row vector which contains the numbers pk, k=1,...,kx, of
  the partition of x with kx row blocks : \eqn{\sum_k p_k=p}}
\item{H}{is a row vector which contains the numbers qh, h=1,...,ky, of the
partition of x with ky column blocks : \eqn{\sum q_h=q}}
\item{r}{is the wanted number of successive solutions}
}

\value{
list with following components
\item{u}{is a p x r matrix of kx row blocks uk (pk x r); uk'*uk = Identity}
\item{v}{is a q x r matrix of ky row blocks vh (qh x r); vh'*vh = Identity}
\item{s2}{is a kx x ky x r array; with r fixed, each matrix contains kxky values \eqn{(u_h'*x_{kh}*v_k)^2}, the partial (squared) singular values relative to \eqn{x_{kh}}}
}

\details{The first solution calculates kx+ky normed vectors: kx vectors
uk[:,1] of Rpk associated to ky vectors vh[,1]'s of Rqh, by maximizing
\eqn{\sum_k \sum_h (u_k[,1]'*x_{kh}*v_h[,1])^2}, with kx+ky norm
constraints.  A value \eqn{(u_k[,1]'*x_{kh}*v_h[,1])^2} measures the
relative link between \eqn{R^{p_k}} and \eqn{R^{q_h}} associated to the
block xkh.

The second solution is obtained from the same criterion, but after
replacing each xhk by xkh-xkh*vh*vh'-uk*uk'xkh+uk*uk'xkh*vh*vh'.  And
so on for the successive solutions 1,2,...,r .  The biggest number of
solutions may be r=inf(pk,qh), when the xkh's are supposed with full
rank; then rmax=min([min(K),min(H)]).

When K=p (or H=q, with t(x)), svdcp function is better.  When H=q and
K=p, it is the usual svd (with squared singular values).

Convergence of algorithm may be not global. So the below proposed
initialisation of the algorithm may be not very suitable for some data
sets.  Several different random initialisations with normed vectors
might be considered and the best result then choosen
}

\references{
Kissita G., Analyse canonique generalisee avec tableau de reference
generalisee. Thesis, Ceremade Paris 9 Dauphine (2003)
}

\examples{
x<-matrix(runif(200),10,20)
s2<-svdbip2(x,c(3,4,3),c(5,5,10),3);s2$s2
s1<-svdbip(x,c(3,4,3),c(5,5,10),3);s1$s2
}


\eof
\name{svdbips}
\title{SVD for bipartitioned matrix x}
\description{SVD for bipartitioned matrix x. SIMULTANEOUS SOLUTIONS. ("simultaneous svdbip")}
\keyword{}
\keyword{}
\alias{svdbips}

\usage{
svdbips(x,K,H,r)
}

\arguments{
\item{x}{is a p x q matrix}
\item{K}{is a row vector which contains the numbers pk, k=1,...,kx, of the
partition of x with kx row blocks : \eqn{\sum_k p_k=p}}
\item{H}{is a row vector which contains the numbers qh, h=1,...,ky, of the
partition of x with ky column blocks : \eqn{\sum_h q_h=q}}
\item{r}{is the wanted number of solutions}
}

\value{
list with following components
\item{u}{is a p x r matrix of kx row blocks uk (pk x r); uk'*uk = Identity}
\item{v}{is a q x r matrix of ky row blocks vh (qh x r); vh'*vh = Identity}
\item{s2}{is a kx x ky x r array; for a fixed solution k, each matrix s2[,,k] contains kxky values \eqn{(u_h'*x_{kh}*v_k)^2}, the "partial (squared) singular values" relative to \eqn{x_{kh}}.}
}

\details{
One set of r solutions is calculated by maximizing \eqn{\sum_i \sum_k \sum_h
(u_k[,i]'*x_{kh}*v_h[,i])^2}, with kx+ky orthonormality constraints (for
each uk and each vh).  For each fixed r value, the solution is totally
new (does'nt consist to complete a previous calculus of one set of r-1
solutions).  rmax=min([min(K),min(H)]).  When r=1, it is svdbip (thus
it is svdcp when r=1 and kx=1).

Convergence of algorithm may be not global. So the below proposed
initialisation of the algorithm may be not very suitable for some data
sets.  Several different random initialisations with normed vectors
might be considered and the best result then choosen....  }

\references{
Lafosse R. & Ten Berge J. A simultaneous CONCOR method for the analysis of two
partitioned matrices. submitted.
}

\examples{
x<-matrix(runif(200),10,20)
s1<-svdbip(x,c(3,4,3),c(5,5,10),2);sum(sum(sum(s1$s2)))
ss<-svdbips(x,c(3,4,3),c(5,5,10),2);sum(sum(sum(ss$s2)))
}


\eof
\name{svdcp}
\title{SVD for a Column Partitioned matrix x}
\description{SVD for a Column Partitioned matrix x. r global successive solutions}
\keyword{}
\keyword{}
\alias{svdcp}

\usage{
svdcp(x,H,r)
}

\arguments{
\item{x}{is a p x q matrix}
\item{H}{is a row vector which contains the numbers qi, i=1,...,kx, of
  the partition of x with kx column blocks xi : \eqn{\sum q_i = q.}}
\item{r}{is the wanted number of successive solutions.}
}

\value{
list with following components
\item{u}{is a p x r matrix; u'*u = Identity}
\item{v}{is a q x r matrix of kx row blocks vi (qi x r); vi'*vi = Identity}
\item{s2}{is a kx x r matrix; each column k contains kx values
\eqn{(u[,k]'*x_i*v_i[,k])^2}, the partial (squared) singular values
relative to xi}
}

\details{
The first solution calculates 1+kx normed vectors: the vector u[,1] of
\eqn{R^p} associated to the kx vectors vi[,1]'s of \eqn{R^{q_i}}. by maximizing
\eqn{\sum_i (u[,1]'*x_i*v_i[,1])^2}, with 1+kx norm constraints.  A
value \eqn{(u[,1]'*x_i*v_i[,1])^2} measures the relative link between
\eqn{R^p} and \eqn{R^{q_i}} associated to xi. It corresponds to a partial squared
singular value notion, since \eqn{\sum_i (u[,1]'*x_i*v_i[,1])^2=s^2},
where s is the usual first singular value of x.

The second solution is obtained from the same criterion, but after
replacing each xi by xi-xi*vi[,1]*vi[,1]'.  And so on for the
successive solutions 1,2,...,r .  The biggest number of solutions may
be r=inf(p,qi), when the xi's are supposed with full rank; then
rmax=min([min(H),p]).
}

\references{
Lafosse R. & Hanafi M.(1997) Concordance d'un tableau avec K tableaux:
Definition de K+1 uples synthetiques. Revue de Statistique Appliquee
vol.45,n.4.
}

\examples{
x<-matrix(runif(200),10,20)
s<-svdcp(x,c(5,5,10),1)
ss<-svd(x);ss$d[1]^2
sum(s$s2)
}

\eof
